==> gwyddion_2.67.orig.tar.xz: gwyddion-2.67/modules/file/file.c <==
/* This is a GENERATED file. */
#include <glib.h>
#include <libgwymodule/gwymodule.h>

static const GwyModuleRecord* register_bundle(void);

static GwyModuleInfo module_info = {
    GWY_MODULE_ABI_VERSION | GWY_MODULE_BUNDLE_FLAG,
    (GwyModuleRegisterFunc)&register_bundle,
    NULL, NULL, NULL, NULL, NULL,
};

GWY_MODULE_QUERY(module_info)

GwyModuleInfo* _gwy_module_query__accurexii_txt(void);
GwyModuleInfo* _gwy_module_query__afmw_spec(void);
GwyModuleInfo* _gwy_module_query__aistfile(void);
GwyModuleInfo* _gwy_module_query__alicona(void);
GwyModuleInfo* _gwy_module_query__ambfile(void);
GwyModuleInfo* _gwy_module_query__ambprofile(void);
GwyModuleInfo* _gwy_module_query__andorsif(void);
GwyModuleInfo* _gwy_module_query__anfatec(void);
GwyModuleInfo* _gwy_module_query__apefile(void);
GwyModuleInfo* _gwy_module_query__ardf(void);
GwyModuleInfo* _gwy_module_query__asciiexport(void);
GwyModuleInfo* _gwy_module_query__asdfile(void);
GwyModuleInfo* _gwy_module_query__assing_afm(void);
GwyModuleInfo* _gwy_module_query__attocube(void);
GwyModuleInfo* _gwy_module_query__bcrfile(void);
GwyModuleInfo* _gwy_module_query__burleigh(void);
GwyModuleInfo* _gwy_module_query__burleigh_bii(void);
GwyModuleInfo* _gwy_module_query__burleigh_exp(void);
GwyModuleInfo* _gwy_module_query__codevfile(void);
GwyModuleInfo* _gwy_module_query__csmfile(void);
GwyModuleInfo* _gwy_module_query__dektakvca(void);
GwyModuleInfo* _gwy_module_query__dektakxml(void);
GwyModuleInfo* _gwy_module_query__dimensionfile(void);
GwyModuleInfo* _gwy_module_query__dmefile(void);
GwyModuleInfo* _gwy_module_query__dm3file(void);
GwyModuleInfo* _gwy_module_query__dumbfile(void);
GwyModuleInfo* _gwy_module_query__ecsfile(void);
GwyModuleInfo* _gwy_module_query__evovisxml(void);
GwyModuleInfo* _gwy_module_query__ezdfile(void);
GwyModuleInfo* _gwy_module_query__femtoscan(void);
GwyModuleInfo* _gwy_module_query__femtoscan_txt(void);
GwyModuleInfo* _gwy_module_query__formats3d(void);
GwyModuleInfo* _gwy_module_query__gdeffile(void);
GwyModuleInfo* _gwy_module_query__gsffile(void);
GwyModuleInfo* _gwy_module_query__gwyfile(void);
GwyModuleInfo* _gwy_module_query__gxyzffile(void);
GwyModuleInfo* _gwy_module_query__hdf4file(void);
GwyModuleInfo* _gwy_module_query__hitachi_afm(void);
GwyModuleInfo* _gwy_module_query__hitachi_sem(void);
GwyModuleInfo* _gwy_module_query__igorfile(void);
GwyModuleInfo* _gwy_module_query__intelliwave(void);
GwyModuleInfo* _gwy_module_query__intematix(void);
GwyModuleInfo* _gwy_module_query__iso28600(void);
GwyModuleInfo* _gwy_module_query__jeol(void);
GwyModuleInfo* _gwy_module_query__jeoltem(void);
GwyModuleInfo* _gwy_module_query__jspmfile(void);
GwyModuleInfo* _gwy_module_query__leica(void);
GwyModuleInfo* _gwy_module_query__lextfile(void);
GwyModuleInfo* _gwy_module_query__magellan(void);
GwyModuleInfo* _gwy_module_query__mapvue(void);
GwyModuleInfo* _gwy_module_query__metropro(void);
GwyModuleInfo* _gwy_module_query__microprof(void);
GwyModuleInfo* _gwy_module_query__miffile(void);
GwyModuleInfo* _gwy_module_query__mifile(void);
GwyModuleInfo* _gwy_module_query__mulfile(void);
GwyModuleInfo* _gwy_module_query__nanoeducator(void);
GwyModuleInfo* _gwy_module_query__nanomagnetics(void);
GwyModuleInfo* _gwy_module_query__nanonics(void);
GwyModuleInfo* _gwy_module_query__nanonis(void);
GwyModuleInfo* _gwy_module_query__nanonis_spec(void);
GwyModuleInfo* _gwy_module_query__nanoscan(void);
GwyModuleInfo* _gwy_module_query__nanoscope_ii(void);
GwyModuleInfo* _gwy_module_query__nanoscope(void);
GwyModuleInfo* _gwy_module_query__nanosystemz(void);
GwyModuleInfo* _gwy_module_query__nanotop(void);
GwyModuleInfo* _gwy_module_query__netcdf(void);
GwyModuleInfo* _gwy_module_query__nmmxyz(void);
GwyModuleInfo* _gwy_module_query__nova_asc(void);
GwyModuleInfo* _gwy_module_query__nt_mdt(void);
GwyModuleInfo* _gwy_module_query__nxiifile(void);
GwyModuleInfo* _gwy_module_query__oldmda(void);
GwyModuleInfo* _gwy_module_query__ols(void);
GwyModuleInfo* _gwy_module_query__ometiff(void);
GwyModuleInfo* _gwy_module_query__omicron(void);
GwyModuleInfo* _gwy_module_query__omicronflat(void);
GwyModuleInfo* _gwy_module_query__omicronmatrix(void);
GwyModuleInfo* _gwy_module_query__opdfile(void);
GwyModuleInfo* _gwy_module_query__phoenix(void);
GwyModuleInfo* _gwy_module_query__pnifile(void);
GwyModuleInfo* _gwy_module_query__pltfile(void);
GwyModuleInfo* _gwy_module_query__princetonspe(void);
GwyModuleInfo* _gwy_module_query__psia(void);
GwyModuleInfo* _gwy_module_query__pt3file(void);
GwyModuleInfo* _gwy_module_query__quazarnpic(void);
GwyModuleInfo* _gwy_module_query__quesant(void);
GwyModuleInfo* _gwy_module_query__rawfile(void);
GwyModuleInfo* _gwy_module_query__rawgraph(void);
GwyModuleInfo* _gwy_module_query__renishaw(void);
GwyModuleInfo* _gwy_module_query__rhk_sm3(void);
GwyModuleInfo* _gwy_module_query__rhk_spm32(void);
GwyModuleInfo* _gwy_module_query__robotics(void);
GwyModuleInfo* _gwy_module_query__s94file(void);
GwyModuleInfo* _gwy_module_query__scafile(void);
GwyModuleInfo* _gwy_module_query__scanfile(void);
GwyModuleInfo* _gwy_module_query__sdfile(void);
GwyModuleInfo* _gwy_module_query__seiko(void);
GwyModuleInfo* _gwy_module_query__sensofar(void);
GwyModuleInfo* _gwy_module_query__sensolytics(void);
GwyModuleInfo* _gwy_module_query__shimadzu(void);
GwyModuleInfo* _gwy_module_query__sicmfile(void);
GwyModuleInfo* _gwy_module_query__sis(void);
GwyModuleInfo* _gwy_module_query__spcfile(void);
GwyModuleInfo* _gwy_module_query__spip_asc(void);
GwyModuleInfo* _gwy_module_query__spmlab(void);
GwyModuleInfo* _gwy_module_query__spmlabf(void);
GwyModuleInfo* _gwy_module_query__stmprg(void);
GwyModuleInfo* _gwy_module_query__stpfile(void);
GwyModuleInfo* _gwy_module_query__tescan(void);
GwyModuleInfo* _gwy_module_query__tiaser(void);
GwyModuleInfo* _gwy_module_query__ttffile(void);
GwyModuleInfo* _gwy_module_query__unisoku(void);
GwyModuleInfo* _gwy_module_query__win_stm(void);
GwyModuleInfo* _gwy_module_query__wipfile(void);
GwyModuleInfo* _gwy_module_query__witec_asc(void);
GwyModuleInfo* _gwy_module_query__witfile(void);
GwyModuleInfo* _gwy_module_query__wsffile(void);
GwyModuleInfo* _gwy_module_query__wrustfile(void);
GwyModuleInfo* _gwy_module_query__wsxmfile(void);
GwyModuleInfo* _gwy_module_query__xyzexport(void);
GwyModuleInfo* _gwy_module_query__zeiss(void);
GwyModuleInfo* _gwy_module_query__zeisslsm(void);
GwyModuleInfo* _gwy_module_query__zemax(void);
GwyModuleInfo* _gwy_module_query__zmgfile(void);

static const GwyModuleRecord modules[] = {
  { _gwy_module_query__accurexii_txt, "accurexii-txt", },
  { _gwy_module_query__afmw_spec, "afmw-spec", },
  { _gwy_module_query__aistfile, "aistfile", },
  { _gwy_module_query__alicona, "alicona", },
  { _gwy_module_query__ambfile, "ambfile", },
  { _gwy_module_query__ambprofile, "ambprofile", },
  { _gwy_module_query__andorsif, "andorsif", },
  { _gwy_module_query__anfatec, "anfatec", },
  { _gwy_module_query__apefile, "apefile", },
  { _gwy_module_query__ardf, "ardf", },
  { _gwy_module_query__asciiexport, "asciiexport", },
  { _gwy_module_query__asdfile, "asdfile", },
  { _gwy_module_query__assing_afm, "assing-afm", },
  { _gwy_module_query__attocube, "attocube", },
  { _gwy_module_query__bcrfile, "bcrfile", },
  { _gwy_module_query__burleigh, "burleigh", },
  { _gwy_module_query__burleigh_bii, "burleigh_bii", },
  { _gwy_module_query__burleigh_exp, "burleigh_exp", },
  { _gwy_module_query__codevfile, "codevfile", },
  { _gwy_module_query__csmfile, "csmfile", },
  { _gwy_module_query__dektakvca, "dektakvca", },
  { _gwy_module_query__dektakxml, "dektakxml", },
  { _gwy_module_query__dimensionfile, "dimensionfile", },
  { _gwy_module_query__dmefile, "dmefile", },
  { _gwy_module_query__dm3file, "dm3file", },
  { _gwy_module_query__dumbfile, "dumbfile", },
  { _gwy_module_query__ecsfile, "ecsfile", },
  { _gwy_module_query__evovisxml, "evovisxml", },
  { _gwy_module_query__ezdfile, "ezdfile", },
  { _gwy_module_query__femtoscan, "femtoscan", },
  { _gwy_module_query__femtoscan_txt, "femtoscan-txt", },
  { _gwy_module_query__formats3d, "formats3d", },
  { _gwy_module_query__gdeffile, "gdeffile", },
  { _gwy_module_query__gsffile, "gsffile", },
  { _gwy_module_query__gwyfile, "gwyfile", },
  { _gwy_module_query__gxyzffile, "gxyzffile", },
  { _gwy_module_query__hdf4file, "hdf4file", },
  { _gwy_module_query__hitachi_afm, "hitachi-afm", },
  { _gwy_module_query__hitachi_sem, "hitachi-sem", },
  { _gwy_module_query__igorfile, "igorfile", },
  { _gwy_module_query__intelliwave, "intelliwave", },
  { _gwy_module_query__intematix, "intematix", },
  { _gwy_module_query__iso28600, "iso28600", },
  { _gwy_module_query__jeol, "jeol", },
  { _gwy_module_query__jeoltem, "jeoltem", },
  { _gwy_module_query__jspmfile, "jspmfile", },
  { _gwy_module_query__leica, "leica", },
  { _gwy_module_query__lextfile, "lextfile", },
  { _gwy_module_query__magellan, "magellan", },
  { _gwy_module_query__mapvue, "mapvue", },
  { _gwy_module_query__metropro, "metropro", },
  { _gwy_module_query__microprof, "microprof", },
  { _gwy_module_query__miffile, "miffile", },
  { _gwy_module_query__mifile, "mifile", },
  { _gwy_module_query__mulfile, "mulfile", },
  { _gwy_module_query__nanoeducator, "nanoeducator", },
  { _gwy_module_query__nanomagnetics, "nanomagnetics", },
  { _gwy_module_query__nanonics, "nanonics", },
  { _gwy_module_query__nanonis, "nanonis", },
  { _gwy_module_query__nanonis_spec, "nanonis-spec", },
  { _gwy_module_query__nanoscan, "nanoscan", },
  { _gwy_module_query__nanoscope_ii, "nanoscope-ii", },
  { _gwy_module_query__nanoscope, "nanoscope", },
  { _gwy_module_query__nanosystemz, "nanosystemz", },
  { _gwy_module_query__nanotop, "nanotop", },
  { _gwy_module_query__netcdf, "netcdf", },
  { _gwy_module_query__nmmxyz, "nmmxyz", },
  { _gwy_module_query__nova_asc, "nova-asc", },
  { _gwy_module_query__nt_mdt, "nt-mdt", },
  { _gwy_module_query__nxiifile, "nxiifile", },
  { _gwy_module_query__oldmda, "oldmda", },
  { _gwy_module_query__ols, "ols", },
  { _gwy_module_query__ometiff, "ometiff", },
  { _gwy_module_query__omicron, "omicron", },
  { _gwy_module_query__omicronflat, "omicronflat", },
  { _gwy_module_query__omicronmatrix, "omicronmatrix", },
  { _gwy_module_query__opdfile, "opdfile", },
  { _gwy_module_query__phoenix, "phoenix", },
  { _gwy_module_query__pnifile, "pnifile", },
  { _gwy_module_query__pltfile, "pltfile", },
  { _gwy_module_query__princetonspe, "princetonspe", },
  { _gwy_module_query__psia, "psia", },
  { _gwy_module_query__pt3file, "pt3file", },
  { _gwy_module_query__quazarnpic, "quazarnpic", },
  { _gwy_module_query__quesant, "quesant", },
  { _gwy_module_query__rawfile, "rawfile", },
  { _gwy_module_query__rawgraph, "rawgraph", },
  { _gwy_module_query__renishaw, "renishaw", },
  { _gwy_module_query__rhk_sm3, "rhk-sm3", },
  { _gwy_module_query__rhk_spm32, "rhk-spm32", },
  { _gwy_module_query__robotics, "robotics", },
  { _gwy_module_query__s94file, "s94file", },
  { _gwy_module_query__scafile, "scafile", },
  { _gwy_module_query__scanfile, "scanfile", },
  { _gwy_module_query__sdfile, "sdfile", },
  { _gwy_module_query__seiko, "seiko", },
  { _gwy_module_query__sensofar, "sensofar", },
  { _gwy_module_query__sensolytics, "sensolytics", },
  { _gwy_module_query__shimadzu, "shimadzu", },
  { _gwy_module_query__sicmfile, "sicmfile", },
  { _gwy_module_query__sis, "sis", },
  { _gwy_module_query__spcfile, "spcfile", },
  { _gwy_module_query__spip_asc, "spip-asc", },
  { _gwy_module_query__spmlab, "spmlab", },
  { _gwy_module_query__spmlabf, "spmlabf", },
  { _gwy_module_query__stmprg, "stmprg", },
  { _gwy_module_query__stpfile, "stpfile", },
  { _gwy_module_query__tescan, "tescan", },
  { _gwy_module_query__tiaser, "tiaser", },
  { _gwy_module_query__ttffile, "ttffile", },
  { _gwy_module_query__unisoku, "unisoku", },
  { _gwy_module_query__win_stm, "win_stm", },
  { _gwy_module_query__wipfile, "wipfile", },
  { _gwy_module_query__witec_asc, "witec-asc", },
  { _gwy_module_query__witfile, "witfile", },
  { _gwy_module_query__wsffile, "wsffile", },
  { _gwy_module_query__wrustfile, "wrustfile", },
  { _gwy_module_query__wsxmfile, "wsxmfile", },
  { _gwy_module_query__xyzexport, "xyzexport", },
  { _gwy_module_query__zeiss, "zeiss", },
  { _gwy_module_query__zeisslsm, "zeisslsm", },
  { _gwy_module_query__zemax, "zemax", },
  { _gwy_module_query__zmgfile, "zmgfile", },
  { NULL, NULL, },
};

static const GwyModuleRecord*
register_bundle(void)
{
    return modules;
}

==> gwyddion-2.69.tar.xz: gwyddion-2.69/modules/file/file.c <==
/* This is a GENERATED file. */
#include <glib.h>
#include <libgwymodule/gwymodule.h>

static const GwyModuleRecord* register_bundle(void);

static GwyModuleInfo module_info = {
    GWY_MODULE_ABI_VERSION | GWY_MODULE_BUNDLE_FLAG,
    (GwyModuleRegisterFunc)&register_bundle,
    NULL, NULL, NULL, NULL, NULL,
};

GWY_MODULE_QUERY(module_info)

GwyModuleInfo* _gwy_module_query__accurell(void);
GwyModuleInfo* _gwy_module_query__accurexii_txt(void);
GwyModuleInfo* _gwy_module_query__afmw_spec(void);
GwyModuleInfo* _gwy_module_query__aistfile(void);
GwyModuleInfo* _gwy_module_query__alicona(void);
GwyModuleInfo* _gwy_module_query__ambfile(void);
GwyModuleInfo* _gwy_module_query__ambprofile(void);
GwyModuleInfo* _gwy_module_query__andorsif(void);
GwyModuleInfo* _gwy_module_query__anfatec(void);
GwyModuleInfo* _gwy_module_query__apefile(void);
GwyModuleInfo* _gwy_module_query__ardf(void);
GwyModuleInfo* _gwy_module_query__asciicmap(void);
GwyModuleInfo* _gwy_module_query__asciiexport(void);
GwyModuleInfo* _gwy_module_query__asdfile(void);
GwyModuleInfo* _gwy_module_query__assing_afm(void);
GwyModuleInfo* _gwy_module_query__attocube(void);
GwyModuleInfo* _gwy_module_query__bcrfile(void);
GwyModuleInfo* _gwy_module_query__burleigh(void);
GwyModuleInfo* _gwy_module_query__burleigh_bii(void);
GwyModuleInfo* _gwy_module_query__burleigh_exp(void);
GwyModuleInfo* _gwy_module_query__codevfile(void);
GwyModuleInfo* _gwy_module_query__csmfile(void);
GwyModuleInfo* _gwy_module_query__dektakvca(void);
GwyModuleInfo* _gwy_module_query__dektakxml(void);
GwyModuleInfo* _gwy_module_query__dimensionfile(void);
GwyModuleInfo* _gwy_module_query__dmefile(void);
GwyModuleInfo* _gwy_module_query__dm3file(void);
GwyModuleInfo* _gwy_module_query__dumbfile(void);
GwyModuleInfo* _gwy_module_query__ecsfile(void);
GwyModuleInfo* _gwy_module_query__evovisxml(void);
GwyModuleInfo* _gwy_module_query__ezdfile(void);
GwyModuleInfo* _gwy_module_query__femtoscan(void);
GwyModuleInfo* _gwy_module_query__femtoscan_txt(void);
GwyModuleInfo* _gwy_module_query__formats3d(void);
GwyModuleInfo* _gwy_module_query__gdeffile(void);
GwyModuleInfo* _gwy_module_query__gsffile(void);
GwyModuleInfo* _gwy_module_query__gwyfile(void);
GwyModuleInfo* _gwy_module_query__gxyzffile(void);
GwyModuleInfo* _gwy_module_query__hdf4file(void);
GwyModuleInfo* _gwy_module_query__hitachi_afm(void);
GwyModuleInfo* _gwy_module_query__hitachi_sem(void);
GwyModuleInfo* _gwy_module_query__igorfile(void);
GwyModuleInfo* _gwy_module_query__intelliwave(void);
GwyModuleInfo* _gwy_module_query__intematix(void);
GwyModuleInfo* _gwy_module_query__iso28600(void);
GwyModuleInfo* _gwy_module_query__jeol(void);
GwyModuleInfo* _gwy_module_query__jeoltem(void);
GwyModuleInfo* _gwy_module_query__jspmfile(void);
GwyModuleInfo* _gwy_module_query__leica(void);
GwyModuleInfo* _gwy_module_query__lextfile(void);
GwyModuleInfo* _gwy_module_query__magellan(void);
GwyModuleInfo* _gwy_module_query__mapvue(void);
GwyModuleInfo* _gwy_module_query__metropro(void);
GwyModuleInfo* _gwy_module_query__microprof(void);
GwyModuleInfo* _gwy_module_query__miffile(void);
GwyModuleInfo* _gwy_module_query__mifile(void);
GwyModuleInfo* _gwy_module_query__mulfile(void);
GwyModuleInfo* _gwy_module_query__nanoeducator(void);
GwyModuleInfo* _gwy_module_query__nanomagnetics(void);
GwyModuleInfo* _gwy_module_query__nanonics(void);
GwyModuleInfo* _gwy_module_query__nanonis(void);
GwyModuleInfo* _gwy_module_query__nanonis_spec(void);
GwyModuleInfo* _gwy_module_query__nanoscan(void);
GwyModuleInfo* _gwy_module_query__nanoscope_ii(void);
GwyModuleInfo* _gwy_module_query__nanoscope(void);
GwyModuleInfo* _gwy_module_query__nanosystemz(void);
GwyModuleInfo* _gwy_module_query__nanotop(void);
GwyModuleInfo* _gwy_module_query__netcdf(void);
GwyModuleInfo* _gwy_module_query__nmmxyz(void);
GwyModuleInfo* _gwy_module_query__nova_asc(void);
GwyModuleInfo* _gwy_module_query__nt_mdt(void);
GwyModuleInfo* _gwy_module_query__nxiifile(void);
GwyModuleInfo* _gwy_module_query__oldmda(void);
GwyModuleInfo* _gwy_module_query__ols(void);
GwyModuleInfo* _gwy_module_query__ometiff(void);
GwyModuleInfo* _gwy_module_query__omicron(void);
GwyModuleInfo* _gwy_module_query__omicronflat(void);
GwyModuleInfo* _gwy_module_query__omicronmatrix(void);
GwyModuleInfo* _gwy_module_query__opdfile(void);
GwyModuleInfo* _gwy_module_query__phoenix(void);
GwyModuleInfo* _gwy_module_query__pnifile(void);
GwyModuleInfo* _gwy_module_query__pltfile(void);
GwyModuleInfo* _gwy_module_query__princetonspe(void);
GwyModuleInfo* _gwy_module_query__psia(void);
GwyModuleInfo* _gwy_module_query__pt3file(void);
GwyModuleInfo* _gwy_module_query__quazarnpic(void);
GwyModuleInfo* _gwy_module_query__quesant(void);
GwyModuleInfo* _gwy_module_query__rawfile(void);
GwyModuleInfo* _gwy_module_query__rawgraph(void);
GwyModuleInfo* _gwy_module_query__renishaw(void);
GwyModuleInfo* _gwy_module_query__rhk_sm3(void);
GwyModuleInfo* _gwy_module_query__rhk_spm32(void);
GwyModuleInfo* _gwy_module_query__rmitmd(void);
GwyModuleInfo* _gwy_module_query__robotics(void);
GwyModuleInfo* _gwy_module_query__s94file(void);
GwyModuleInfo* _gwy_module_query__scafile(void);
GwyModuleInfo* _gwy_module_query__scanfile(void);
GwyModuleInfo* _gwy_module_query__sdfile(void);
GwyModuleInfo* _gwy_module_query__seiko(void);
GwyModuleInfo* _gwy_module_query__sensofar(void);
GwyModuleInfo* _gwy_module_query__sensolytics(void);
GwyModuleInfo* _gwy_module_query__shimadzu(void);
GwyModuleInfo* _gwy_module_query__sicmfile(void);
GwyModuleInfo* _gwy_module_query__sis(void);
GwyModuleInfo* _gwy_module_query__spcfile(void);
GwyModuleInfo* _gwy_module_query__spip_asc(void);
GwyModuleInfo* _gwy_module_query__spmlab(void);
GwyModuleInfo* _gwy_module_query__spmlabf(void);
GwyModuleInfo* _gwy_module_query__stmprg(void);
GwyModuleInfo* _gwy_module_query__stpfile(void);
GwyModuleInfo* _gwy_module_query__talos(void);
GwyModuleInfo* _gwy_module_query__tescan(void);
GwyModuleInfo* _gwy_module_query__tiaser(void);
GwyModuleInfo* _gwy_module_query__ttffile(void);
GwyModuleInfo* _gwy_module_query__unisoku(void);
GwyModuleInfo* _gwy_module_query__win_stm(void);
GwyModuleInfo* _gwy_module_query__wipfile(void);
GwyModuleInfo* _gwy_module_query__witec_asc(void);
GwyModuleInfo* _gwy_module_query__witfile(void);
GwyModuleInfo* _gwy_module_query__wsffile(void);
GwyModuleInfo* _gwy_module_query__wrustfile(void);
GwyModuleInfo* _gwy_module_query__wsxmfile(void);
GwyModuleInfo* _gwy_module_query__xyzexport(void);
GwyModuleInfo* _gwy_module_query__zeiss(void);
GwyModuleInfo* _gwy_module_query__zeisslsm(void);
GwyModuleInfo* _gwy_module_query__zemax(void);
GwyModuleInfo* _gwy_module_query__zmgfile(void);

static const GwyModuleRecord modules[] = {
  { _gwy_module_query__accurell, "accurell", },
  { _gwy_module_query__accurexii_txt, "accurexii-txt", },
  { _gwy_module_query__afmw_spec, "afmw-spec", },
  { _gwy_module_query__aistfile, "aistfile", },
  { _gwy_module_query__alicona, "alicona", },
  { _gwy_module_query__ambfile, "ambfile", },
  { _gwy_module_query__ambprofile, "ambprofile", },
  { _gwy_module_query__andorsif, "andorsif", },
  { _gwy_module_query__anfatec, "anfatec", },
  { _gwy_module_query__apefile, "apefile", },
  { _gwy_module_query__ardf, "ardf", },
  { _gwy_module_query__asciicmap, "asciicmap", },
  { _gwy_module_query__asciiexport, "asciiexport", },
  { _gwy_module_query__asdfile, "asdfile", },
  { _gwy_module_query__assing_afm, "assing-afm", },
  { _gwy_module_query__attocube, "attocube", },
  { _gwy_module_query__bcrfile, "bcrfile", },
  { _gwy_module_query__burleigh, "burleigh", },
  { _gwy_module_query__burleigh_bii, "burleigh_bii", },
  { _gwy_module_query__burleigh_exp, "burleigh_exp", },
  { _gwy_module_query__codevfile, "codevfile", },
  { _gwy_module_query__csmfile, "csmfile", },
  { _gwy_module_query__dektakvca, "dektakvca", },
  { _gwy_module_query__dektakxml, "dektakxml", },
  { _gwy_module_query__dimensionfile, "dimensionfile", },
  { _gwy_module_query__dmefile, "dmefile", },
  { _gwy_module_query__dm3file, "dm3file", },
  { _gwy_module_query__dumbfile, "dumbfile", },
  { _gwy_module_query__ecsfile, "ecsfile", },
  { _gwy_module_query__evovisxml, "evovisxml", },
  { _gwy_module_query__ezdfile, "ezdfile", },
  { _gwy_module_query__femtoscan, "femtoscan", },
  { _gwy_module_query__femtoscan_txt, "femtoscan-txt", },
  { _gwy_module_query__formats3d, "formats3d", },
  { _gwy_module_query__gdeffile, "gdeffile", },
  { _gwy_module_query__gsffile, "gsffile", },
  { _gwy_module_query__gwyfile, "gwyfile", },
  { _gwy_module_query__gxyzffile, "gxyzffile", },
  { _gwy_module_query__hdf4file, "hdf4file", },
  { _gwy_module_query__hitachi_afm, "hitachi-afm", },
  { _gwy_module_query__hitachi_sem, "hitachi-sem", },
  { _gwy_module_query__igorfile, "igorfile", },
  { _gwy_module_query__intelliwave, "intelliwave", },
  { _gwy_module_query__intematix, "intematix", },
  { _gwy_module_query__iso28600, "iso28600", },
  { _gwy_module_query__jeol, "jeol", },
  { _gwy_module_query__jeoltem, "jeoltem", },
  { _gwy_module_query__jspmfile, "jspmfile", },
  { _gwy_module_query__leica, "leica", },
  { _gwy_module_query__lextfile, "lextfile", },
  { _gwy_module_query__magellan, "magellan", },
  { _gwy_module_query__mapvue, "mapvue", },
  { _gwy_module_query__metropro, "metropro", },
  { _gwy_module_query__microprof, "microprof", },
  { _gwy_module_query__miffile, "miffile", },
  { _gwy_module_query__mifile, "mifile", },
  { _gwy_module_query__mulfile, "mulfile", },
  { _gwy_module_query__nanoeducator, "nanoeducator", },
  { _gwy_module_query__nanomagnetics, "nanomagnetics", },
  { _gwy_module_query__nanonics, "nanonics", },
  { _gwy_module_query__nanonis, "nanonis", },
  { _gwy_module_query__nanonis_spec, "nanonis-spec", },
  { _gwy_module_query__nanoscan, "nanoscan", },
  { _gwy_module_query__nanoscope_ii, "nanoscope-ii", },
  { _gwy_module_query__nanoscope, "nanoscope", },
  { _gwy_module_query__nanosystemz, "nanosystemz", },
  { _gwy_module_query__nanotop, "nanotop", },
  { _gwy_module_query__netcdf, "netcdf", },
  { _gwy_module_query__nmmxyz, "nmmxyz", },
  { _gwy_module_query__nova_asc, "nova-asc", },
  { _gwy_module_query__nt_mdt, "nt-mdt", },
  { _gwy_module_query__nxiifile, "nxiifile", },
  { _gwy_module_query__oldmda, "oldmda", },
  { _gwy_module_query__ols, "ols", },
  { _gwy_module_query__ometiff, "ometiff", },
  { _gwy_module_query__omicron, "omicron", },
  { _gwy_module_query__omicronflat, "omicronflat", },
  { _gwy_module_query__omicronmatrix, "omicronmatrix", },
  { _gwy_module_query__opdfile, "opdfile", },
  { _gwy_module_query__phoenix, "phoenix", },
  { _gwy_module_query__pnifile, "pnifile", },
  { _gwy_module_query__pltfile, "pltfile", },
  { _gwy_module_query__princetonspe, "princetonspe", },
  { _gwy_module_query__psia, "psia", },
  { _gwy_module_query__pt3file, "pt3file", },
  { _gwy_module_query__quazarnpic, "quazarnpic", },
  { _gwy_module_query__quesant, "quesant", },
  { _gwy_module_query__rawfile, "rawfile", },
  { _gwy_module_query__rawgraph, "rawgraph", },
  { _gwy_module_query__renishaw, "renishaw", },
  { _gwy_module_query__rhk_sm3, "rhk-sm3", },
  { _gwy_module_query__rhk_spm32, "rhk-spm32", },
  { _gwy_module_query__rmitmd, "rmitmd", },
  { _gwy_module_query__robotics, "robotics", },
  { _gwy_module_query__s94file, "s94file", },
  { _gwy_module_query__scafile, "scafile", },
  { _gwy_module_query__scanfile, "scanfile", },
  { _gwy_module_query__sdfile, "sdfile", },
  { _gwy_module_query__seiko, "seiko", },
  { _gwy_module_query__sensofar, "sensofar", },
  { _gwy_module_query__sensolytics, "sensolytics", },
  { _gwy_module_query__shimadzu, "shimadzu", },
  { _gwy_module_query__sicmfile, "sicmfile", },
  { _gwy_module_query__sis, "sis", },
  { _gwy_module_query__spcfile, "spcfile", },
  { _gwy_module_query__spip_asc, "spip-asc", },
  { _gwy_module_query__spmlab, "spmlab", },
  { _gwy_module_query__spmlabf, "spmlabf", },
  { _gwy_module_query__stmprg, "stmprg", },
  { _gwy_module_query__stpfile, "stpfile", },
  { _gwy_module_query__talos, "talos", },
  { _gwy_module_query__tescan, "tescan", },
  { _gwy_module_query__tiaser, "tiaser", },
  { _gwy_module_query__ttffile, "ttffile", },
  { _gwy_module_query__unisoku, "unisoku", },
  { _gwy_module_query__win_stm, "win_stm", },
  { _gwy_module_query__wipfile, "wipfile", },
  { _gwy_module_query__witec_asc, "witec-asc", },
  { _gwy_module_query__witfile, "witfile", },
  { _gwy_module_query__wsffile, "wsffile", },
  { _gwy_module_query__wrustfile, "wrustfile", },
  { _gwy_module_query__wsxmfile, "wsxmfile", },
  { _gwy_module_query__xyzexport, "xyzexport", },
  { _gwy_module_query__zeiss, "zeiss", },
  { _gwy_module_query__zeisslsm, "zeisslsm", },
  { _gwy_module_query__zemax, "zemax", },
  { _gwy_module_query__zmgfile, "zmgfile", },
  { NULL, NULL, },
};

static const GwyModuleRecord*
register_bundle(void)
{
    return modules;
}
